@@ -16,13 +16,16 @@
 #' @keywords betaMC ci internal
 #' @noRd
 .CI <- function(object,
-                alpha = c(0.05, 0.01, 0.001)) {
+                alpha = NULL) {
   stopifnot(
-    methods::is(
+    inherits(
       object,
       "betamc"
     )
   )
+  if (is.null(alpha)) {
+    alpha <- object$args$alpha
+  }
   probs <- .PCProbs(alpha = alpha)
   thetahatstar <- do.call(
     what = "rbind",
